@@ -24,13 +24,12 @@
 #include <ksslcertificatemanager.h>
 #include <klocalizedstring.h>
 
-#include <QDebug>
 #include <QUrl>
-#include <QStringList>
 #include <QSslKey>
 #include <QSslCipher>
 #include <QHostAddress>
 #include <QNetworkProxy>
+#include <QNetworkReply>
 #include <QAuthenticator>
 
 static KTcpSocket::SslVersion kSslVersionFromQ(QSsl::SslProtocol protocol)
@@ -135,7 +134,7 @@ class CipherCc
 public:
     CipherCc()
     {
-        foreach (const QSslCipher &c, QSslSocket::supportedCiphers()) {
+        foreach (const QSslCipher &c, QSslConfiguration::supportedCiphers()) {
             allCiphers.insert(c.name(), c);
         }
     }
@@ -375,7 +374,7 @@ public:
         q->showSslErrors(); //H4X
         QList<KSslError> kErrors;
         kErrors.reserve(errors.size());
-        foreach (const QSslError &e, errors) {
+        for (const QSslError &e : errors) {
             kErrors.append(KSslError(e));
         }
         emit q->sslErrors(kErrors);
@@ -406,8 +405,7 @@ public:
     void maybeLoadCertificates()
     {
         if (!certificatesLoaded) {
-            sock.setCaCertificates(KSslCertificateManager::self()->caCertificates());
-            certificatesLoaded = true;
+            q->setCaCertificates(KSslCertificateManager::self()->caCertificates());
         }
     }
 
@@ -683,7 +681,7 @@ void KTcpSocket::addCaCertificates(const QList<QSslCertificate> &certificates)
 QList<QSslCertificate> KTcpSocket::caCertificates() const
 {
     d->maybeLoadCertificates();
-    return d->sock.caCertificates();
+    return d->sock.sslConfiguration().caCertificates();
 }
 
 QList<KSslCipher> KTcpSocket::ciphers() const
@@ -721,7 +719,9 @@ KSslCipher KTcpSocket::sessionCipher() const
 
 void KTcpSocket::setCaCertificates(const QList<QSslCertificate> &certificates)
 {
-    d->sock.setCaCertificates(certificates);
+    QSslConfiguration configuration = d->sock.sslConfiguration();
+    configuration.setCaCertificates(certificates);
+    d->sock.setSslConfiguration(configuration);
     d->certificatesLoaded = true;
 }
 
@@ -733,7 +733,9 @@ void KTcpSocket::setCiphers(const QList<KSslCipher> &ciphers)
     foreach (const KSslCipher &c, d->ciphers) {
         cl.append(d->ccc.converted(c));
     }
-    d->sock.setCiphers(cl);
+    QSslConfiguration configuration = d->sock.sslConfiguration();
+    configuration.setCiphers(cl);
+    d->sock.setSslConfiguration(configuration);
 }
 
 void KTcpSocket::setLocalCertificate(const QSslCertificate &certificate)
@@ -1046,9 +1048,9 @@ int KSslCipher::usedBits() const
 QList<KSslCipher> KSslCipher::supportedCiphers()
 {
     QList<KSslCipher> ret;
-    QList<QSslCipher> candidates = QSslSocket::supportedCiphers();
+    const QList<QSslCipher> candidates = QSslConfiguration::supportedCiphers();
     ret.reserve(candidates.size());
-    foreach (const QSslCipher &c, candidates) {
+    for (const QSslCipher &c : candidates) {
         ret.append(KSslCipher(c));
     }
     return ret;
@@ -1096,6 +1098,24 @@ KSslErrorUiData::KSslErrorUiData(const QSslSocket *socket)
     d->bits = socket->sessionCipher().supportedBits();
 }
 
+KSslErrorUiData::KSslErrorUiData(const QNetworkReply *reply, const QList<QSslError> &sslErrors)
+    : d(new Private())
+{
+    const auto sslConfig = reply->sslConfiguration();
+    d->certificateChain = sslConfig.peerCertificateChain();
+
+    d->sslErrors.reserve(sslErrors.size());
+    for (const QSslError &e : sslErrors) {
+        d->sslErrors.append(KSslError(e));
+    }
+
+    d->host = reply->request().url().host();
+    d->sslProtocol = sslConfig.sessionCipher().protocolString();
+    d->cipher = sslConfig.sessionCipher().name();
+    d->usedBits = sslConfig.sessionCipher().usedBits();
+    d->bits = sslConfig.sessionCipher().supportedBits();
+}
+
 KSslErrorUiData::KSslErrorUiData(const KSslErrorUiData &other)
     : d(new Private(*other.d))
 {}
